==> haskell-pgp-wordlist-0.1.0.2-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pgp-wordlist
version: 0.1.0.2
id: pgp-wordlist-0.1.0.2-6hepuWpWQ8zFtJDyCaa08u
key: pgp-wordlist-0.1.0.2-6hepuWpWQ8zFtJDyCaa08u
license: BSD-3-Clause
copyright: David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer: David Luposchainsky <dluposchainsky(λ)gmail.com>
author: David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage: https://github.com/quchen/pgp-wordlist
synopsis: Translate between binary data and a human-readable
          collection of words.
description:
    Translate between binary data and a human-readable
    collection of words.
    .
    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.
    .
    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.
    .
    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.
category: Data, Serialization
abi: acc7d6359418f708a2639e1bc5ce9057
exposed: True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words
import-dirs: /usr/lib/ghc-8.6.4/site-local/pgp-wordlist-0.1.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/pgp-wordlist-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/pgp-wordlist-0.1.0.2
hs-libraries: HSpgp-wordlist-0.1.0.2-6hepuWpWQ8zFtJDyCaa08u
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock
haddock-html: /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pgp-wordlist-0.1.0.2-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pgp-wordlist
version: 0.1.0.2
id: pgp-wordlist-0.1.0.2-HpuGpEc2OqFBW9J7ATByKg
key: pgp-wordlist-0.1.0.2-HpuGpEc2OqFBW9J7ATByKg
license: BSD-3-Clause
copyright: David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer: David Luposchainsky <dluposchainsky(λ)gmail.com>
author: David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage: https://github.com/quchen/pgp-wordlist
synopsis: Translate between binary data and a human-readable
          collection of words.
description:
    Translate between binary data and a human-readable
    collection of words.
    .
    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.
    .
    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.
    .
    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.
category: Data, Serialization
abi: 365cc9577ed326419952a913a7c595e9
exposed: True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words
import-dirs: /usr/lib/ghc-8.6.4/site-local/pgp-wordlist-0.1.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/pgp-wordlist-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/pgp-wordlist-0.1.0.2
hs-libraries: HSpgp-wordlist-0.1.0.2-HpuGpEc2OqFBW9J7ATByKg
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock
haddock-html: /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
